@@ -130,17 +130,19 @@ def resolve_sub_portfolios(
     return personal_data.resolve_sub_portfolios(master_portfolio, sub_portfolios, market_prices)
 
 
-def get_portfolio_filled_orders_deltas(
+async def get_portfolio_filled_orders_deltas(
     previous_portfolio_content: dict[str, dict[str, decimal.Decimal]],
     updated_portfolio_content: dict[str, dict[str, decimal.Decimal]],
     filled_or_partially_filled_orders: list[personal_data.Order],
     unknown_filled_or_cancelled_orders: list[personal_data.Order],
-    ignored_filled_quantity_per_order_exchange_id: dict[str, decimal.Decimal]
+    ignored_filled_quantity_per_order_exchange_id: dict[str, decimal.Decimal],
+    randomize_secondary_checks: bool,
+    timeout: typing.Optional[float],
 ) -> personal_data.ResolvedOrdersPortoflioDelta:
-    return personal_data.get_portfolio_filled_orders_deltas(
+    return await personal_data.get_portfolio_filled_orders_deltas(
         previous_portfolio_content, updated_portfolio_content, 
         filled_or_partially_filled_orders, unknown_filled_or_cancelled_orders, 
-        ignored_filled_quantity_per_order_exchange_id
+        ignored_filled_quantity_per_order_exchange_id, randomize_secondary_checks, timeout
     )
 
 
@@ -171,3 +173,7 @@ def get_master_checked_sub_portfolio_update(
     updated_sub_portfolio: dict[str, dict[str, decimal.Decimal]],
 ) -> dict[str, dict[str, decimal.Decimal]]:
     return personal_data.get_master_checked_sub_portfolio_update(updated_portfolio_content, updated_sub_portfolio)
+
+
+def get_fees_only_asset_deltas_from_orders(orders: list[personal_data.Order]) -> dict[str, decimal.Decimal]:
+    return personal_data.get_fees_only_asset_deltas_from_orders(orders)
