@@ -13,15 +13,25 @@
 #
 #  You should have received a copy of the GNU Lesser General Public
 #  License along with this library.
-import ccxt.async_support
+import decimal
+
 import octobot_trading.exchanges.connectors.ccxt.ccxt_client_util as ccxt_client_util
 
 
-def parse_markets(exchange_name, market_filter) -> dict:
-    client = getattr(ccxt.async_support, exchange_name)()
+def parse_markets(exchange_name: str, additional_client_config: dict, market_filter) -> dict:
+    exchange_class = ccxt_client_util.ccxt_exchange_class_factory(exchange_name)
+    config = {
+        **additional_client_config,
+        **ccxt_client_util.get_custom_domain_config(exchange_class)
+    }
+    client = exchange_class(config)
     ccxt_client_util.load_markets_from_cache(client, market_filter)
     return client.markets
 
 
 def get_fees(market_status) -> dict:
     return ccxt_client_util.get_fees(market_status)
+
+
+def get_contract_size(market_status: dict) -> decimal.Decimal:
+    return decimal.Decimal(str(ccxt_client_util.get_market_status_contract_size(market_status)))
