@@ -25,9 +25,9 @@ import asyncio
 import ccxt.async_support as ccxt
 import octobot_commons.enums as commons_enums
 import octobot_commons.tree as commons_tree
+import octobot_commons.constants as commons_constants
 import octobot_commons.html_util as html_util
-
-from octobot_commons import number_util
+import octobot_commons.number_util as number_util
 
 import octobot_trading.enums as enums
 import octobot_trading.constants as constants
@@ -115,6 +115,9 @@ class RestExchange(abstract_exchange.AbstractExchange):
     # Set True when the "limit" param when fetching order books is taken into account
     SUPPORTS_CUSTOM_LIMIT_ORDER_BOOK_FETCH = False
 
+    # set True when fetch_tickers can sometimes miss symbols. In this case, the connector will try to fix it
+    CAN_MISS_TICKERS_IN_ALL_TICKERS = True
+
     # text content of errors due to orders not found errors
     EXCHANGE_ORDER_NOT_FOUND_ERRORS: typing.List[typing.Iterable[str]] = []
     # when ccxt is raising ccxt.ExchangeError instead of ccxt.AuthenticationError on api key permissions issue
@@ -139,6 +142,8 @@ class RestExchange(abstract_exchange.AbstractExchange):
     EXCHANGE_ORDER_IMMEDIATELY_TRIGGER_ERRORS: typing.List[typing.Iterable[str]] = []
     # text content of errors due to an order that can't be cancelled on exchange (because filled or already cancelled)
     EXCHANGE_ORDER_UNCANCELLABLE_ERRORS: typing.List[typing.Iterable[str]] = []
+    # text content of errors due to max open orders being reached
+    EXCHANGE_MAX_ORDERS_FOR_MARKET_REACHED_ERRORS: typing.List[typing.Iterable[str]] = []
     # set when the exchange can allow users to pay fees in a custom currency (ex: BNB on binance)
     LOCAL_FEES_CURRENCIES: typing.List[str] = []
 
@@ -261,7 +266,7 @@ class RestExchange(abstract_exchange.AbstractExchange):
         except ccxt.InsufficientFunds as e:
             self._on_missing_funds_err(e, order_type, symbol, quantity, price, stop_price)
         except ccxt.MarketClosed as err:
-            raise errors.MarketClosedError(html_util.get_html_summary_if_relevant(err)) from err
+            raise errors.MarketClosedError(f"{symbol} {html_util.get_html_summary_if_relevant(err)}") from err
         except (ccxt.NotSupported, NotImplementedError) as err:
             raise errors.NotSupported(err) from err
         except (errors.AuthenticationError, ccxt.AuthenticationError) as err:
@@ -306,6 +311,11 @@ class RestExchange(abstract_exchange.AbstractExchange):
                     f"Exchange is refusing this order request on this account because "
                     f"of its compliancy requirements."
                 ) from e
+            if self.is_exchange_max_orders_for_market_reached_error(e):
+                raise errors.ExchangeMaxOrdersForMarketReachedError(
+                    f"Error when handling order {html_util.get_html_summary_if_relevant(e)}. "
+                    f"Exchange is refusing this order: the maximum number of orders for this market has been reached."
+                ) from e
             if self.is_exchange_closed_position_error(e):
                 raise errors.ExchangeClosedPositionError(
                     f"Error when handling order {html_util.get_html_summary_if_relevant(e)}. "
@@ -594,6 +604,9 @@ class RestExchange(abstract_exchange.AbstractExchange):
             else constants.DEFAULT_MAX_DEFAULT_ORDERS_COUNT
         )
 
+    def uses_demo_trading_instead_of_sandbox(self) -> bool:
+        return False
+
     def _apply_contract_size(self, value, contract_size):
         if value is None:
             return value
@@ -1132,6 +1145,11 @@ class RestExchange(abstract_exchange.AbstractExchange):
             return exchanges_util.is_error_on_this_type(error, self.EXCHANGE_ORDER_UNCANCELLABLE_ERRORS)
         return False
 
+    def is_exchange_max_orders_for_market_reached_error(self, error: BaseException) -> bool:
+        if self.EXCHANGE_MAX_ORDERS_FOR_MARKET_REACHED_ERRORS:
+            return exchanges_util.is_error_on_this_type(error, self.EXCHANGE_MAX_ORDERS_FOR_MARKET_REACHED_ERRORS)
+        return False
+
     def is_exchange_internal_sync_error(self, error: BaseException) -> bool:
         if self.EXCHANGE_INTERNAL_SYNC_ERRORS:
             return exchanges_util.is_error_on_this_type(error, self.EXCHANGE_INTERNAL_SYNC_ERRORS)
@@ -1181,6 +1199,10 @@ class RestExchange(abstract_exchange.AbstractExchange):
     async def get_autofilled_exchange_details(cls, aiohttp_session, tentacle_config, exchange_name):
         raise NotImplementedError("get_autofilled_exchange_details is not implemented")
 
+    @staticmethod
+    def get_default_reference_market(exchange_name: str) -> str:
+        return commons_constants.DEFAULT_REFERENCE_MARKET
+
 
     """
     Parsers todo remove ?
