@@ -19,13 +19,15 @@ import enum
 
 class QuantityType(enum.Enum):
     DELTA = ""
+    DELTA_EXPLICIT = "d"
     DELTA_QUOTE = "q"
+    DELTA_BASE = "b"
     PERCENT = "%"
     AVAILABLE = "a"
-    POSITION = "p"
     ENTRY = "e"
     AVAILABLE_PERCENT = "a%"
     POSITION_PERCENT = "p%"
+    POSITION_PERCENT_ALIAS = "p"
     ENTRY_PERCENT = "e%"
     CURRENT_SYMBOL_ASSETS_PERCENT = "s%"
     TRADED_SYMBOLS_ASSETS_PERCENT = "t%"
