@@ -17,6 +17,11 @@ import copy
 import decimal
 import typing
 import itertools
+import math
+import asyncio
+import time
+import threading
+import random
 
 import octobot_trading.personal_data.portfolios.asset as asset
 import octobot_trading.personal_data.portfolios.assets
@@ -31,6 +36,7 @@ import octobot_trading.errors as errors
 import octobot_commons.constants as commons_constants
 import octobot_commons.logging as commons_logging
 import octobot_commons.symbols as symbol_util
+import octobot_commons.list_util as list_util
 
 import numpy as numpy
 
@@ -545,18 +551,21 @@ def get_missing_master_portfolio_values_update(
     return updates
 
 
-def get_portfolio_filled_orders_deltas(
+async def get_portfolio_filled_orders_deltas(
     previous_portfolio_content: dict[str, dict[str, decimal.Decimal]],
     updated_portfolio_content: dict[str, dict[str, decimal.Decimal]],
     filled_or_partially_filled_orders: list[order_import.Order],
     unknown_filled_or_cancelled_orders: list[order_import.Order],
-    ignored_filled_quantity_per_order_exchange_id: dict[str, decimal.Decimal]
+    ignored_filled_quantity_per_order_exchange_id: dict[str, decimal.Decimal],
+    randomize_secondary_checks: bool,
+    timeout: typing.Optional[float],
 ) -> resolved_orders_portfolio_delta.ResolvedOrdersPortoflioDelta:
     portfolios_asset_deltas = _get_assets_delta_from_portfolio(previous_portfolio_content, updated_portfolio_content)
     if unknown_filled_or_cancelled_orders:
-        return _compute_most_probable_assets_deltas_from_orders_considering_unknown_orders(
+        return await _compute_most_probable_assets_deltas_from_orders_considering_unknown_orders(
             filled_or_partially_filled_orders, portfolios_asset_deltas, 
-            unknown_filled_or_cancelled_orders, ignored_filled_quantity_per_order_exchange_id
+            unknown_filled_or_cancelled_orders, ignored_filled_quantity_per_order_exchange_id,
+            randomize_secondary_checks, timeout
         )
     else:
         orders_asset_deltas, expected_fee_related_deltas, possible_fees_asset_deltas, _ = get_assets_delta_from_orders(
@@ -591,28 +600,62 @@ def _can_orders_compensate_each_other(unknown_filled_or_cancelled_orders: list[o
     return bool(symbols_with_buy_orders.intersection(symbols_with_sell_orders))
 
 
-def _get_optimistic_order_counts_to_fill(unknown_filled_or_cancelled_orders: list[order_import.Order]) -> list[int]:
-    # try to avoid iterating all possitibilies when possible. Worse cases are when 50% of the orders are 
-    # filled (their possible combinations are really numerous), process those cases last.
-    # start at 1 to avoid considering no filled orders (already considered in best_inferred_resolved_delta)
-    all_possibilities = list(range(1, len(unknown_filled_or_cancelled_orders) + 1))
-    sorted_orders_to_fill_counts = []
-    for index in range(len(all_possibilities) // 2):
-        # 1. add most filled orders counts
-        sorted_orders_to_fill_counts.append(all_possibilities[-(index + 1)])
-        # 2. add least filled orders counts
-        sorted_orders_to_fill_counts.append(all_possibilities[index])
-    if len(all_possibilities) % 2 == 1:
-        # last: add middle filled orders count if any
-        sorted_orders_to_fill_counts.append(all_possibilities[len(all_possibilities) // 2])
-    return sorted_orders_to_fill_counts
+def _get_combinations_count(total_elements, selected_elements):
+    return math.factorial(total_elements) // (
+        math.factorial(selected_elements) * math.factorial(total_elements - selected_elements)
+    )
 
 
-def _compute_most_probable_assets_deltas_from_orders_considering_unknown_orders(
+def _get_order_counts_to_fill_and_combinations_count(
+    unknown_filled_or_cancelled_orders: list[order_import.Order]
+) -> list[tuple[int, int]]:
+    """
+    returns the order count of each combination and the number of combinations for each count
+    sorted by the number of combinations, lowest first
+    """
+    combinations_per_count = {
+        orders_to_fill_count: _get_combinations_count(len(unknown_filled_or_cancelled_orders), orders_to_fill_count)
+        for orders_to_fill_count in range(1, len(unknown_filled_or_cancelled_orders) + 1)
+    }
+    return [
+        (orders_to_fill_count, combinations_per_count[orders_to_fill_count])
+        for orders_to_fill_count in sorted(
+            combinations_per_count,
+            # key 1: lowest combinations count first (combinations_per_count[x])
+            # key 2: largest filled orders count first (x)
+            key=lambda x: combinations_per_count[x] * 100 - x
+        )
+    ]
+
+
+def _get_quicky_and_secondary_order_combinations_checks(
+    unknown_filled_or_cancelled_orders: list[order_import.Order]
+) -> tuple[list[int], list[int], list[tuple[int, int]]]:
+    sorted_orders_to_fill_counts_and_combinations_count = _get_order_counts_to_fill_and_combinations_count(
+        unknown_filled_or_cancelled_orders
+    )
+    return [
+        orders_to_fill_count
+        for orders_to_fill_count, combinations_count in sorted_orders_to_fill_counts_and_combinations_count
+        if combinations_count <= constants.MAX_ORDER_INFERENCE_QUICK_CHECK_COMBINATIONS_COUNT
+    ], [
+        orders_to_fill_count
+        for orders_to_fill_count, combinations_count in sorted_orders_to_fill_counts_and_combinations_count
+        if constants.MAX_ORDER_INFERENCE_QUICK_CHECK_COMBINATIONS_COUNT < combinations_count <= constants.MAX_ORDER_SECONDARY_INFERENCE_COMBINATIONS_COUNT
+    ], [
+        (orders_to_fill_count, combinations_count)
+        for orders_to_fill_count, combinations_count in sorted_orders_to_fill_counts_and_combinations_count
+        if combinations_count > constants.MAX_ORDER_SECONDARY_INFERENCE_COMBINATIONS_COUNT
+    ]
+
+
+async def _compute_most_probable_assets_deltas_from_orders_considering_unknown_orders(
     filled_or_partially_filled_orders: list[order_import.Order],
     portfolios_asset_deltas: dict[str, dict[str, decimal.Decimal]],
     unknown_filled_or_cancelled_orders: list[order_import.Order],
-    ignored_filled_quantity_per_order_exchange_id: dict[str, decimal.Decimal]
+    ignored_filled_quantity_per_order_exchange_id: dict[str, decimal.Decimal],
+    randomize_secondary_checks: bool,
+    timeout: typing.Optional[float],
 ) -> resolved_orders_portfolio_delta.ResolvedOrdersPortoflioDelta:
     """
     Returns the most probable deltas which are the ones that can be best explained by given orders
@@ -634,7 +677,7 @@ def _compute_most_probable_assets_deltas_from_orders_considering_unknown_orders(
         known_filled_orders_resolved_delta = resolved_orders_portfolio_delta.ResolvedOrdersPortoflioDelta()
     # init with all cancelled orders and explained+unexplained portfolio deltas from known filled orders
     best_inferred_resolved_delta = resolved_orders_portfolio_delta.ResolvedOrdersPortoflioDelta(
-        inferred_cancelled_orders=unknown_filled_or_cancelled_orders,
+        inferred_cancelled_orders= list(unknown_filled_or_cancelled_orders), # avoid modifying the original list
     ).merge_order_deltas(known_filled_orders_resolved_delta, portfolios_asset_deltas)
     if (
         not best_inferred_resolved_delta.unexplained_orders_deltas 
@@ -644,17 +687,183 @@ def _compute_most_probable_assets_deltas_from_orders_considering_unknown_orders(
         return _get_cleared_inferred_resolved_delta(
             best_inferred_resolved_delta, portfolios_asset_deltas
         )
-    post_filled_orders_portfolio_asset_deltas = resolved_orders_portfolio_delta.filter_empty_deltas(
+    remaining_portfolio_asset_deltas = resolved_orders_portfolio_delta.filter_empty_deltas(
         sub_portfolio_data.get_content_after_deltas(
             portfolios_asset_deltas, _reverse_portfolio_deltas(
                 best_inferred_resolved_delta.explained_orders_deltas
             ), apply_available_deltas=True
         )
     )
-    sorted_orders_to_fill_counts = _get_optimistic_order_counts_to_fill(unknown_filled_or_cancelled_orders)
+    # split orders by symbol and compute deltas together for each linked order
+    orders_per_symbol = {
+        symbol: [order for order in unknown_filled_or_cancelled_orders if order.symbol == symbol]
+        for symbol in list_util.deduplicate([order.symbol for order in unknown_filled_or_cancelled_orders])
+    }
+    if len(orders_per_symbol) == 1 or len(unknown_filled_or_cancelled_orders) <= 10:
+        # few orders or all orders are for the same symbol: compute deltas together 
+        # more accurate that symbol per symbol as it minimizes deltas but more expensive in CPU when many orders
+        return await _compute_most_probable_assets_deltas_from_orders_considering_unknown_orders_for_symbol(
+            unknown_filled_or_cancelled_orders, ignored_filled_quantity_per_order_exchange_id,  remaining_portfolio_asset_deltas, known_filled_orders_resolved_delta, portfolios_asset_deltas, best_inferred_resolved_delta, randomize_secondary_checks, timeout
+        )
+    else:
+        filled_orders = []
+        # orders are for different symbols: compute deltas separately when possible to limit the number of combinations
+        initial_best_inferred_resolved_delta = resolved_orders_portfolio_delta.ResolvedOrdersPortoflioDelta()
+        for symbol_orders in orders_per_symbol.values():
+            symbol_best_inferred_resolved_delta = await _compute_most_probable_assets_deltas_from_orders_considering_unknown_orders_for_symbol(
+                symbol_orders, ignored_filled_quantity_per_order_exchange_id, remaining_portfolio_asset_deltas, known_filled_orders_resolved_delta, portfolios_asset_deltas, best_inferred_resolved_delta, randomize_secondary_checks, timeout
+            )
+            filled_orders.extend(symbol_best_inferred_resolved_delta.inferred_filled_orders)
+            known_filled_orders_resolved_delta = symbol_best_inferred_resolved_delta
+            known_filled_orders_resolved_delta.inferred_filled_orders.clear()
+            known_filled_orders_resolved_delta.inferred_cancelled_orders.clear()
+            best_inferred_resolved_delta = initial_best_inferred_resolved_delta.merge_order_deltas(
+                known_filled_orders_resolved_delta, portfolios_asset_deltas
+            )
+            remaining_portfolio_asset_deltas = resolved_orders_portfolio_delta.filter_empty_deltas(
+                sub_portfolio_data.get_content_after_deltas(
+                    portfolios_asset_deltas, _reverse_portfolio_deltas(
+                        symbol_best_inferred_resolved_delta.explained_orders_deltas
+                    ), apply_available_deltas=True
+                )
+            )
+            if not remaining_portfolio_asset_deltas:
+                # all filled orders have been identified: stop here
+                break
+        
+
+        orders_asset_deltas, expected_fee_related_deltas, possible_fees_asset_deltas, _ = get_assets_delta_from_orders(
+            filled_or_partially_filled_orders + filled_orders, ignored_filled_quantity_per_order_exchange_id, True
+        )
+        resolved_delta = compute_assets_deltas_from_orders(
+            orders_asset_deltas, expected_fee_related_deltas, possible_fees_asset_deltas, 
+            portfolios_asset_deltas, 
+            allow_portfolio_delta_shrinking=False, 
+            register_missed_partial_delta_as_ignored=True, 
+            ignore_order_unrelated_deltas=False,
+            ignore_order_extra_deltas=True,
+        )
+        resolved_delta.inferred_filled_orders = filled_orders
+        resolved_delta.inferred_cancelled_orders = [order for order in unknown_filled_or_cancelled_orders if order not in filled_orders]
+        return _get_cleared_inferred_resolved_delta(resolved_delta, portfolios_asset_deltas)
+
+
+async def _compute_most_probable_assets_deltas_from_orders_considering_unknown_orders_for_symbol(
+    unknown_filled_or_cancelled_orders: list[order_import.Order],
+    ignored_filled_quantity_per_order_exchange_id: dict[str, decimal.Decimal],
+    post_filled_orders_portfolio_asset_deltas: dict[str, dict[str, decimal.Decimal]],
+    known_filled_orders_resolved_delta: resolved_orders_portfolio_delta.ResolvedOrdersPortoflioDelta,
+    portfolios_asset_deltas: dict[str, dict[str, decimal.Decimal]],
+    best_inferred_resolved_delta: resolved_orders_portfolio_delta.ResolvedOrdersPortoflioDelta,
+    randomize_secondary_checks: bool,
+    timeout: typing.Optional[float],
+) -> resolved_orders_portfolio_delta.ResolvedOrdersPortoflioDelta:
+    inference_start_time = time.time()
+    symbols = set(order.symbol for order in unknown_filled_or_cancelled_orders)
+    quick_check_orders_to_fill_counts, secondary_check_orders_to_fill_counts, skipped_combinations = _get_quicky_and_secondary_order_combinations_checks(
+        unknown_filled_or_cancelled_orders
+    )
+    
     compute_forecasted_fees = False # don't compute forecasted fees as it will 10x the time to compute the deltas
+    best_inferred_resolved_delta = _compute_most_probable_assets_deltas_from_orders_considering_unknown_orders_after_filled_orders_deltas(
+        quick_check_orders_to_fill_counts, 
+        unknown_filled_or_cancelled_orders, ignored_filled_quantity_per_order_exchange_id, 
+        compute_forecasted_fees, post_filled_orders_portfolio_asset_deltas, known_filled_orders_resolved_delta, 
+        portfolios_asset_deltas, best_inferred_resolved_delta, None
+    )
+    if not best_inferred_resolved_delta.is_fully_explained() and secondary_check_orders_to_fill_counts:
+        # best_inferred_resolved_delta is not found in quick checks, try the (slow) rest in a separate thread
+        # to release async loop
+        if skipped_combinations:
+            min_skipped = min(s[0] for s in skipped_combinations)
+            max_skipped = max(s[0] for s in skipped_combinations)
+            skipped = (
+                f" Skipping {','.join(symbols)} [{min_skipped}:{max_skipped}] filled orders among {len(unknown_filled_or_cancelled_orders)} (which is {len(skipped_combinations)} combinations out of {len(unknown_filled_or_cancelled_orders)}) as they contain more than {constants.MAX_ORDER_SECONDARY_INFERENCE_COMBINATIONS_COUNT} possibilities."
+            )
+        else:
+            skipped = ""
+        commons_logging.get_logger(__name__).error(
+            f"Best {','.join(symbols)} inferred resolved delta not found in {len(quick_check_orders_to_fill_counts)} "
+            f"quick check configurations ({', '.join(str(count) for count in quick_check_orders_to_fill_counts)}), "
+            f"trying the (slow) {len(secondary_check_orders_to_fill_counts)} other configurations in a separate thread.{skipped}"
+        )
+        # Note on the thread: as this is a python thread, it will not really run 
+        # concurrently or on different cores, the current CPU will swap between 
+        # this thread and the async loop thread, therefore making everything slower but
+        # ensuring the async loop is not blocked, which is the goal of this thread
+        auto_canceller_task = None
+        try:
+            if randomize_secondary_checks:
+                random.shuffle(secondary_check_orders_to_fill_counts)
+            cancelled_event = threading.Event()
+            if timeout is not None:
+                remaining_timeout = timeout - (time.time() - inference_start_time)
+                if remaining_timeout <= 0:
+                    # timeout already reached: cancel thread immediately
+                    commons_logging.get_logger(__name__).error(
+                        f"Timeout of {timeout}s was already reached while computing most probable assets "
+                        f"deltas before using background thread for symbol {','.join(symbols)}"
+                    )
+                    return best_inferred_resolved_delta
+                async def _auto_canceller():
+                    await asyncio.sleep(remaining_timeout)
+                    if not cancelled_event.is_set():
+                        commons_logging.get_logger(__name__).warning(
+                            f"Timeout: {remaining_timeout}s (remaining of intial {timeout}s) while computing most "
+                            f"probable assets deltas for {len(secondary_check_orders_to_fill_counts)} "
+                            f"orders for symbol {','.join(symbols)} - cancelling background thread"
+                        )
+                        cancelled_event.set()
+                auto_canceller_task = asyncio.create_task(_auto_canceller())
+            best_inferred_resolved_delta = await asyncio.to_thread(    
+                _compute_most_probable_assets_deltas_from_orders_considering_unknown_orders_after_filled_orders_deltas,
+                secondary_check_orders_to_fill_counts, 
+                unknown_filled_or_cancelled_orders, ignored_filled_quantity_per_order_exchange_id, 
+                compute_forecasted_fees, post_filled_orders_portfolio_asset_deltas, known_filled_orders_resolved_delta, 
+                portfolios_asset_deltas, best_inferred_resolved_delta, cancelled_event
+            )
+        except (asyncio.CancelledError, asyncio.TimeoutError) as err:
+            # catch both cancelled and timeout errors to cancel thread when it happens
+            if isinstance(err, asyncio.CancelledError) and cancelled_event.is_set():
+                # this is an expected cancellation: continue (don't raise)
+                return best_inferred_resolved_delta
+            commons_logging.get_logger(__name__).warning(
+                f"{err.__class__.__name__}:{err} while computing most probable assets deltas for {len(secondary_check_orders_to_fill_counts)} orders for symbol {','.join(symbols)} - cancelling background thread"
+            )
+            # cancel thread to avoid having it run for nothing
+            cancelled_event.set()
+            raise
+        finally:
+            if auto_canceller_task is not None and not auto_canceller_task.done():
+                auto_canceller_task.cancel()
+
+    return _get_cleared_inferred_resolved_delta(best_inferred_resolved_delta, portfolios_asset_deltas)
+
+
+def _compute_most_probable_assets_deltas_from_orders_considering_unknown_orders_after_filled_orders_deltas(
+    sorted_orders_to_fill_counts: typing.Iterable[int],
+    unknown_filled_or_cancelled_orders: list[order_import.Order],
+    ignored_filled_quantity_per_order_exchange_id: dict[str, decimal.Decimal],
+    compute_forecasted_fees: bool,
+    post_filled_orders_portfolio_asset_deltas: dict[str, dict[str, decimal.Decimal]],
+    known_filled_orders_resolved_delta: resolved_orders_portfolio_delta.ResolvedOrdersPortoflioDelta,
+    portfolios_asset_deltas: dict[str, dict[str, decimal.Decimal]],
+    best_inferred_resolved_delta: resolved_orders_portfolio_delta.ResolvedOrdersPortoflioDelta,
+    cancelled_event: typing.Optional[threading.Event],
+) -> resolved_orders_portfolio_delta.ResolvedOrdersPortoflioDelta:
+    last_sleep_time = time.time()
     for orders_to_fill_count in sorted_orders_to_fill_counts:
         for filled_orders_combination in itertools.combinations(unknown_filled_or_cancelled_orders, orders_to_fill_count):
+            if cancelled_event:
+                if time.time() - last_sleep_time > constants.MAX_ORDER_INFERENCE_ITERATIONS_DURATION:
+                    # If cancelled_event is set, this is running in a thread. As this function requires a lot of CPU, force 
+                    # it to sleep at regular intervals to let other threads as well since real multi-threading doesn't exist in python du to the GIL.
+                    # This is somewhat similar to a lower priority thread, even though this doesn't really exist in python
+                    time.sleep(constants.ORDER_INFERENCE_SLEEP_TIME)
+                    last_sleep_time = time.time()
+                if cancelled_event.is_set():
+                    # cancelled, complete function immediately
+                    return best_inferred_resolved_delta
             potential_filled_orders_combination = list(filled_orders_combination)
             (
                 orders_asset_deltas, expected_fee_related_deltas, possible_fees_asset_deltas, counted_exchange_fee_deltas
@@ -694,9 +903,7 @@ def _compute_most_probable_assets_deltas_from_orders_considering_unknown_orders(
             ]
             try:
                 if merged_inferred_resolved_delta_candidate.is_fully_explained():
-                    return _get_cleared_inferred_resolved_delta(
-                        merged_inferred_resolved_delta_candidate, portfolios_asset_deltas
-                    )
+                    return merged_inferred_resolved_delta_candidate
                 elif merged_inferred_resolved_delta_candidate.is_more_probable_than(best_inferred_resolved_delta):
                     best_inferred_resolved_delta = merged_inferred_resolved_delta_candidate
             except KeyError as err:
@@ -704,7 +911,7 @@ def _compute_most_probable_assets_deltas_from_orders_considering_unknown_orders(
                 commons_logging.get_logger(__name__).error(
                     f"Unexpected error when computing most probable assets deltas from orders: {err}"
                 )
-    return _get_cleared_inferred_resolved_delta(best_inferred_resolved_delta, portfolios_asset_deltas)
+    return best_inferred_resolved_delta
 
 
 def _get_cleared_inferred_resolved_delta(
@@ -982,6 +1189,32 @@ def get_assets_delta_from_orders(
         expected_fee_related_deltas, possible_fee_related_deltas, counted_exchange_fee_deltas
     )
 
+
+def get_fees_only_asset_deltas_from_orders(orders: list[order_import.Order]) -> dict[str, decimal.Decimal]:
+    order_traded_assets = set()
+    for order in orders:
+        symbol = symbol_util.parse_symbol(order.symbol)
+        order_traded_assets.add(symbol.base)
+        order_traded_assets.add(symbol.quote)
+    return {
+        currency: delta
+        for currency, delta in _get_fees_assets_deltas_from_orders(orders).items()
+        if currency not in order_traded_assets
+    }
+
+
+def _get_fees_assets_deltas_from_orders(orders: list[order_import.Order]) -> dict[str, decimal.Decimal]:
+    asset_deltas = {}
+    for order in orders:
+        if (fees := order.fee) and fees[enums.FeePropertyColumns.COST.value]:
+            fee_asset = fees[enums.FeePropertyColumns.CURRENCY.value]
+            if fee_asset not in asset_deltas:
+                asset_deltas[fee_asset] = -decimal.Decimal(str(fees[enums.FeePropertyColumns.COST.value]))
+            else:
+                asset_deltas[fee_asset] -= decimal.Decimal(str(fees[enums.FeePropertyColumns.COST.value])) 
+    return asset_deltas
+
+
 def _get_other_asset_forecasted_fees(
     order: order_import.Order, forecasted_fees: dict, 
     exchange_local_fees_currency_price: dict[str, dict[str, decimal.Decimal]]
