@@ -76,11 +76,11 @@ class ValueConverter:
         return self._check_currency_initialization(currency, currency_value)
 
     def get_usd_like_value(self, currency, quantity, raise_error=True, init_price_fetchers=True):
-        if self.is_usd_like_coin(currency):
+        if symbol_util.is_usd_like_coin(currency):
             return quantity
         if symbol := self.get_usd_like_symbol_from_symbols(currency, self.last_prices_by_trading_pair):
             base, quote = symbol_util.parse_symbol(symbol).base_and_quote()
-            usd_like_currency = base if self.is_usd_like_coin(base) else quote
+            usd_like_currency = base if symbol_util.is_usd_like_coin(base) else quote
             return self.evaluate_value(
                 currency, quantity, raise_error=raise_error,
                 target_currency=usd_like_currency, init_price_fetchers=init_price_fetchers
@@ -92,13 +92,21 @@ class ValueConverter:
 
     @staticmethod
     def get_usd_like_symbol_from_symbols(currency: str, symbols) -> str:
+        try:
+            return ValueConverter.get_usd_like_symbols_from_symbols(currency, symbols)[0]
+        except IndexError:
+            return None
+
+    @staticmethod
+    def get_usd_like_symbols_from_symbols(currency: str, symbols) -> list:
         # look for symbols using USD_LIKE_COINS priorities
+        usd_like_symbols = []
         for usd_like_coin in commons_constants.USD_LIKE_COINS:
             for symbol in symbols:
                 base_and_quote = symbol_util.parse_symbol(symbol).base_and_quote()
                 if currency in base_and_quote and usd_like_coin in base_and_quote:
-                    return symbol
-        return None
+                    usd_like_symbols.append(symbol)
+        return usd_like_symbols
 
     @staticmethod
     def can_convert_symbol_to_usd_like(symbol: str) -> bool:
@@ -108,10 +116,6 @@ class ValueConverter:
                 return True
         return False
 
-    @staticmethod
-    def is_usd_like_coin(coin) -> bool:
-        return coin in commons_constants.USD_LIKE_COINS
-
     def _check_currency_initialization(self, currency, currency_value):
         """
         Check if the currency has to be removed from self.initializing_symbol_prices and return currency_value
