@@ -62,12 +62,13 @@ class Position(util.Initializable):
         self.fee_to_close = constants.ZERO
 
         # Size
-        self.quantity = constants.ZERO
-        self.size = constants.ZERO
+        self.quantity = constants.ZERO  # unleverage size
+        self.size = constants.ZERO  # size of the position (in asset)
         self.already_reduced_size = constants.ZERO
-        self.value = constants.ZERO
-        self.initial_margin = constants.ZERO
-        self.margin = constants.ZERO
+        self.value = constants.ZERO # value of the position
+        self.initial_margin = constants.ZERO    # locked funds from the wallet to maintain position
+        self.margin = constants.ZERO    # initial_margin + fee to close
+        self.auto_deposit_margin = False
 
         # PNL
         self.unrealized_pnl = constants.ZERO
@@ -131,7 +132,7 @@ class Position(util.Initializable):
 
     def _update(self, position_id, exchange_position_id, symbol, currency, market, timestamp,
                 entry_price, mark_price, liquidation_price,
-                quantity, size, value, initial_margin,
+                quantity, size, value, initial_margin, auto_deposit_margin,
                 unrealized_pnl, realised_pnl, fee_to_close,
                 status=None):
         changed: bool = False
@@ -147,6 +148,8 @@ class Position(util.Initializable):
 
         if self._should_change(self.timestamp, timestamp):
             self.timestamp = timestamp
+            # if we have a timestamp, it's a real trader => need to format timestamp if necessary
+            self.creation_time = self.exchange_manager.exchange.get_uniformized_timestamp(timestamp)
         if not self.timestamp:
             if not timestamp:
                 self.creation_time = self.exchange_manager.exchange.get_exchange_current_time()
@@ -172,6 +175,10 @@ class Position(util.Initializable):
             self._update_margin()
             changed = True
 
+        if self._should_change(self.auto_deposit_margin, auto_deposit_margin):
+            self.auto_deposit_margin = auto_deposit_margin
+            changed = True
+
         if self._should_change(self.unrealized_pnl, unrealized_pnl):
             self.unrealized_pnl = unrealized_pnl
             changed = True
@@ -202,8 +209,15 @@ class Position(util.Initializable):
 
         self._update_quantity_or_size_if_necessary()
         # update side after quantity as it relies on self.quantity
-        self._update_side(not entry_price)
+        self._update_side(
+            not entry_price,
+            creation_timestamp=self.exchange_manager.exchange.get_uniformized_timestamp(timestamp)
+        )
         self._update_prices_if_necessary(mark_price)
+        if changed:
+            # ensure fee to close and margin are up to date now that all other attributes are set
+            self.update_fee_to_close()
+            self._update_margin()
         return changed
 
     async def ensure_position_initialized(self, **kwargs):
@@ -226,7 +240,7 @@ class Position(util.Initializable):
         try:
             with self.update_or_restore():
                 if mark_price is not None:
-                    self._update_mark_price(mark_price)
+                    self._update_mark_price(mark_price, force_entry_check=bool(update_size or update_margin))
                 if update_margin is not None:
                     self._update_size_from_margin(update_margin)
                 if update_size is not None:
@@ -251,27 +265,27 @@ class Position(util.Initializable):
         self._on_size_update(size_update, realised_pnl_update, self.unrealized_pnl, False)
         await self.close()
 
-    def _update_mark_price(self, mark_price, check_liquidation=True):
+    def _update_mark_price(self, mark_price, check_liquidation=True, force_entry_check=False):
         """
         Updates position mark_price and triggers size related attributes update
         :param mark_price: the update mark_price
         """
         self.mark_price = mark_price
-        self._update_prices_if_necessary(mark_price)
+        self._update_prices_if_necessary(mark_price, force_entry_check=force_entry_check)
         if check_liquidation:
             self._check_for_liquidation()
         if not self.is_idle() and self.exchange_manager.is_simulated:
             self.update_value()
             self.update_pnl()
 
-    def _update_prices_if_necessary(self, mark_price):
+    def _update_prices_if_necessary(self, mark_price, force_entry_check=False):
         """
         Update the position entry price and mark price when their value is 0 or when the position is new
         :param mark_price: the current mark_price
         """
         if self.mark_price == constants.ZERO:
             self.mark_price = mark_price
-        if self.entry_price == constants.ZERO:
+        if self.entry_price == constants.ZERO and (force_entry_check or not self.is_idle()):
             self.entry_price = mark_price
 
     def _update_size_from_margin(self, margin_update):
@@ -298,7 +312,7 @@ class Position(util.Initializable):
                 or (self.is_short() and order.is_short())
         )
 
-    def update_from_order(self, order):
+    async def update_from_order(self, order):
         """
         Update position size and entry price from filled order portfolio
         :param order: the filled order instance
@@ -306,7 +320,7 @@ class Position(util.Initializable):
         """
         # consider the order filled price as the current reference price for pnl computation
         # do not check liquidation as our position might be closed by this order
-        self._update_mark_price(order.filled_price, check_liquidation=False)
+        self._update_mark_price(order.filled_price, check_liquidation=False, force_entry_check=True)
 
         # get size to close to check if closing
         size_to_close = self.get_quantity_to_close()
@@ -335,11 +349,17 @@ class Position(util.Initializable):
             if self.size == constants.ZERO:
                 self.creation_time = self.exchange_manager.exchange.get_exchange_current_time()
             self.update_average_entry_price(size_update, order.filled_price)
+        elif self._is_update_reversing_side(size_update):
+            # don't use size_update here as it is larger than size
+            self._update_exit_data(size_to_close, self.mark_price)
         elif self._is_update_decreasing_size(size_update):
             self._update_exit_data(size_update, self.mark_price)
 
         # update size and realised pnl
         self._update_size(size_update, realised_pnl_update=realised_pnl_fees_update, trigger_source=trigger_source)
+        if size_to_close and self.is_idle():
+            # don't keep previous position pnl etc when position is now idle
+            await self.close()
 
     def _update_realized_pnl_from_order(self, order):
         """
@@ -396,6 +416,15 @@ class Position(util.Initializable):
             return size_update < constants.ZERO
         return size_update > constants.ZERO
 
+    def _is_update_reversing_side(self, size_update):
+        """
+        :param size_update: the size update
+        :return: True if this update will reverse position side
+        """
+        if self.is_long():
+            return self.size + size_update < constants.ZERO
+        return self.size + size_update > constants.ZERO
+
     def _is_update_closing(self, size_update):
         """
         :param size_update: the size update
@@ -407,6 +436,12 @@ class Position(util.Initializable):
             return self.size + size_update <= constants.ZERO
         return self.size + size_update >= constants.ZERO
 
+    def is_exclusively_using_exchange_position_details(self) -> bool:
+        return (
+            self.exchange_manager.exchange_personal_data.positions_manager
+            .is_exclusively_using_exchange_position_details
+        )
+
     def _update_size(self, size_update, realised_pnl_update=constants.ZERO,
                      trigger_source=enums.PNLTransactionSource.UNKNOWN):
         """
@@ -417,14 +452,20 @@ class Position(util.Initializable):
         """
         margin_update = constants.ZERO
         is_update_increasing_position_size = self._is_update_increasing_size(size_update)
-        if self._is_update_decreasing_size(size_update):
+        if self._is_update_reversing_side(size_update):
+            realised_pnl_update += self._update_realized_pnl_from_size_update(
+                self.get_quantity_to_close(), is_closing=True,
+                update_price=self.mark_price, trigger_source=trigger_source
+            )
+        elif self._is_update_decreasing_size(size_update):
             realised_pnl_update += self._update_realized_pnl_from_size_update(
                 size_update, is_closing=self._is_update_closing(size_update),
-                update_price=self.mark_price, trigger_source=trigger_source)
+                update_price=self.mark_price, trigger_source=trigger_source
+            )
         self._check_and_update_size(size_update)
         self._update_quantity()
         self._update_side(True)
-        if self.exchange_manager.is_simulated:
+        if self.exchange_manager.is_simulated and not self.is_exclusively_using_exchange_position_details():
             margin_update = self._update_initial_margin()
             self.update_fee_to_close()
             self.update_liquidation_price()
@@ -487,7 +528,7 @@ class Position(util.Initializable):
 
     def _update_quantity(self):
         """
-        Update position quantity from position quantity
+        Update position quantity from position size
         """
         self.quantity = self.size / self.symbol_contract.current_leverage
 
@@ -684,15 +725,17 @@ class Position(util.Initializable):
         """
         self.exchange_manager.exchange_personal_data.portfolio_manager.portfolio.update_portfolio_from_pnl(self)
 
-    def _on_side_update(self, reset_entry_price):
+    def _on_side_update(self, reset_entry_price, creation_timestamp=0):
         """
         Resets the side related data when a position side changes
         """
         if reset_entry_price:
             self._reset_entry_price()
         self.exit_price = constants.ZERO
-        self.creation_time = self.exchange_manager.exchange.get_exchange_current_time()
-        logging.get_logger(self.get_logger_name()).info(f"Changed position side: now {self.side.name}")
+        self.already_reduced_size = constants.ZERO
+        # use update_timestamp when available, use exchange time otherwise
+        self.creation_time = creation_timestamp or self.exchange_manager.exchange.get_exchange_current_time()
+        logging.get_logger(self.get_logger_name()).debug(f"Changed position side: now {self.side.name}")
         # update position state if necessary
         positions_states.create_position_state(self)
 
@@ -722,6 +765,9 @@ class Position(util.Initializable):
     def update_from_raw(self, raw_position):
         symbol = str(raw_position.get(enums.ExchangeConstantsPositionColumns.SYMBOL.value, None))
         currency, market = self.exchange_manager.get_exchange_quote_and_base(symbol)
+        position_id = (
+            self.position_id or raw_position.get(enums.ExchangeConstantsPositionColumns.LOCAL_ID.value) or symbol
+        )
         # side is managed locally, do not parse it
         return self._update(
             symbol=symbol,
@@ -736,7 +782,10 @@ class Position(util.Initializable):
             value=raw_position.get(enums.ExchangeConstantsPositionColumns.NOTIONAL.value, constants.ZERO),
             initial_margin=raw_position.get(enums.ExchangeConstantsPositionColumns.INITIAL_MARGIN.value,
                                             constants.ZERO),
-            position_id=self.position_id or symbol,
+            auto_deposit_margin=raw_position.get(
+                enums.ExchangeConstantsPositionColumns.AUTO_DEPOSIT_MARGIN.value, False
+            ),
+            position_id=position_id,
             exchange_position_id=str(raw_position.get(enums.ExchangeConstantsPositionColumns.ID.value, None) or symbol),
             timestamp=raw_position.get(enums.ExchangeConstantsPositionColumns.TIMESTAMP.value, 0),
             unrealized_pnl=raw_position.get(enums.ExchangeConstantsPositionColumns.UNREALIZED_PNL.value,
@@ -748,7 +797,8 @@ class Position(util.Initializable):
 
     def to_dict(self):
         return {
-            enums.ExchangeConstantsPositionColumns.ID.value: self.position_id,
+            enums.ExchangeConstantsPositionColumns.ID.value: self.exchange_position_id,
+            enums.ExchangeConstantsPositionColumns.LOCAL_ID.value: self.position_id,
             enums.ExchangeConstantsPositionColumns.SYMBOL.value: self.symbol,
             enums.ExchangeConstantsPositionColumns.STATUS.value: self.status.value,
             enums.ExchangeConstantsPositionColumns.TIMESTAMP.value: self.timestamp,
@@ -757,19 +807,27 @@ class Position(util.Initializable):
             enums.ExchangeConstantsPositionColumns.SIZE.value: self.size,
             enums.ExchangeConstantsPositionColumns.NOTIONAL.value: self.value,
             enums.ExchangeConstantsPositionColumns.INITIAL_MARGIN.value: self.initial_margin,
+            enums.ExchangeConstantsPositionColumns.AUTO_DEPOSIT_MARGIN.value: self.auto_deposit_margin,
             enums.ExchangeConstantsPositionColumns.COLLATERAL.value: self.margin,
+            enums.ExchangeConstantsPositionColumns.LEVERAGE.value: self.symbol_contract.current_leverage,
+            enums.ExchangeConstantsPositionColumns.MARGIN_TYPE.value: self.symbol_contract.margin_type.value
+                if self.symbol_contract and self.symbol_contract.margin_type else None,
+            enums.ExchangeConstantsPositionColumns.POSITION_MODE.value: self.symbol_contract.position_mode.value
+                if self.symbol_contract and self.symbol_contract.position_mode else None,
             enums.ExchangeConstantsPositionColumns.ENTRY_PRICE.value: self.entry_price,
             enums.ExchangeConstantsPositionColumns.MARK_PRICE.value: self.mark_price,
             enums.ExchangeConstantsPositionColumns.LIQUIDATION_PRICE.value: self.liquidation_price,
             enums.ExchangeConstantsPositionColumns.UNREALIZED_PNL.value: self.unrealized_pnl,
             enums.ExchangeConstantsPositionColumns.REALISED_PNL.value: self.realised_pnl,
+            enums.ExchangeConstantsPositionColumns.MAINTENANCE_MARGIN_RATE.value: self.symbol_contract.maintenance_margin_rate,
         }
 
     def _check_for_liquidation(self):
         """
         _check_for_liquidation defines rules for a position to be liquidated
         """
-        if self.liquidation_price.is_nan():
+        if self.liquidation_price.is_nan() or self.is_exclusively_using_exchange_position_details():
+            # should skip liquidation check
             return
         if (self.is_short()
             and self.mark_price >= self.liquidation_price > constants.ZERO) or (
@@ -793,7 +851,7 @@ class Position(util.Initializable):
         self.entry_price = constants.ZERO
         self._update_prices_if_necessary(self.mark_price)
 
-    def _update_side(self, reset_entry_price):
+    def _update_side(self, reset_entry_price, creation_timestamp=0):
         """
         Checks if self.side still represents the position side
         Only relevant when account is using one way position mode
@@ -811,7 +869,7 @@ class Position(util.Initializable):
             else:
                 self.side = enums.PositionSide.UNKNOWN
             if changed_side:
-                self._on_side_update(reset_entry_price)
+                self._on_side_update(reset_entry_price, creation_timestamp)
 
     def __str__(self):
         return self.to_string()
@@ -857,6 +915,7 @@ class Position(util.Initializable):
         self.unrealized_pnl = constants.ZERO
         self.realised_pnl = constants.ZERO
         self.creation_time = 0
+        self.timestamp = 0
         self.on_pnl_update()  # notify portfolio to reset unrealized PNL
         positions_states.create_position_state(self)
 
