@@ -112,6 +112,7 @@ class TestOrderFactory:
             self.DEFAULT_SYMBOL,
             price,
             quantity,
+            quantity_filled=decimal.Decimal("0.66"),
             price=price,
             order_id="123",
             tag="tag",
@@ -123,6 +124,7 @@ class TestOrderFactory:
         created_from_dict = personal_data.create_order_from_dict(trader_inst, order_dict)
         assert created_from_dict.origin_price == limit_order.origin_price == price
         assert created_from_dict.origin_quantity == limit_order.origin_quantity == quantity
+        assert created_from_dict.filled_quantity == limit_order.filled_quantity == decimal.Decimal("0.66")
         assert created_from_dict.__class__ is limit_order.__class__ == personal_data.SellLimitOrder
         assert created_from_dict.symbol == limit_order.symbol == self.DEFAULT_SYMBOL
         assert created_from_dict.order_id == limit_order.order_id == "123"
@@ -134,6 +136,7 @@ class TestOrderFactory:
         # associated_entry_ids are not copied
         assert created_from_dict.associated_entry_ids is None
         assert created_from_dict.trigger_above is limit_order.trigger_above is True
+        assert created_from_dict.exchange_order_id # ensure exchange_order_id is generated
         assert limit_order.associated_entry_ids == ["1"]
 
 
@@ -146,6 +149,7 @@ class TestOrderFactory:
             quantity,
             price=price,
             trigger_above=False,
+            exchange_order_id="123",
         )
         order_dict = limit_order.to_dict()
         created_from_dict = personal_data.create_order_from_dict(trader_inst, order_dict)
@@ -160,6 +164,7 @@ class TestOrderFactory:
         # associated_entry_ids are not copied
         assert created_from_dict.associated_entry_ids is None
         assert created_from_dict.trigger_above is limit_order.trigger_above is False
+        assert created_from_dict.exchange_order_id == "123"
         assert limit_order.associated_entry_ids is None
 
         await self.stop(exchange_manager)
